---
name: Enhancement request
about: Anything you’d like to see in scanpy?
title: ''
labels: enhancement
assignees: ''
---

<!-- What kind of feature would you like to request? -->
- [ ] Additional function parameters / changed functionality / changed defaults?
- [ ] New analysis tool: A simple analysis tool you have been using and are missing in `sc.tools`?
- [ ] New plotting function: A kind of plot you would like to seein `sc.pl`?
- [ ] External tools: Do you know an existing package that should go into `sc.external.*`?
- [ ] Other?

<!-- Please describe your wishes below: -->
...
